@@ -1,11 +1,13 @@
-# import pyvisa
-class Keithley6487:
-    """ "
+from lip_pps_run_manager.setup_manager import VISADevice
+
+
+class Keithley6487(VISADevice):
+    """
     Class for the keithley 6487 PicoAmmeter
     """
 
-    def __init__(self):
-        pass
+    def __init__(self, device_name: str, resource_string: str):
+        super().__init__(device_type="Keithley6487", device_name=device_name, resource_string=resource_string)
 
     def set_voltage(self, voltage: float):
         pass
